CREATE TABLE schema_migrations (
	version INTEGER NOT NULL
)

CREATE TABLE chat_rooms (
  	_id        INTEGER PRIMARY KEY AUTOINCREMENT,
  	id          INTEGER NOT NULL,
  	type       TEXT,
  	members     TEXT,
  	active_member_ids TEXT,
  	last_log_id    INTEGER,
  	last_message    TEXT,
  	last_updated_at INTEGER,
  	unread_count    INTEGER,
  	watermarks    TEXT,
  	temporary_message TEXT,
	v TEXT,
	ext TEXT,
	last_read_log_id INTEGER,
	last_update_seen_id INTEGER,
	active_members_count INTEGER,
	meta	TEXT,
	is_hint	INTEGER,
	private_meta	TEXT,
	last_chat_log_type INTEGER DEFAULT 1,
	schat_token INTEGER DEFAULT 0,
	last_skey_token INTEGER DEFAULT 0,
	last_pk_tokens TEXT,
	link_id INTEGER DEFAULT -1
)

CREATE UNIQUE INDEX chat_rooms_index1 ON chat_rooms(id)
CREATE INDEX chat_rooms_index2 ON chat_rooms(last_updated_at)
CREATE INDEX chat_rooms_index4 ON chat_rooms(unread_count)
CREATE INDEX chat_rooms_index5 ON chat_rooms(link_id)

CREATE TABLE public_key_info (
  	_id        INTEGER PRIMARY KEY AUTOINCREMENT,
  	user_id    INTEGER NOT NULL,
  	pub_key_token INTEGER NOT NULL,
    encrypt_key TEXT,
    sign_key    TEXT,
    chain_sign  TEXT,
    create_at  INTEGER,
    pk_set_token INTEGER NOT NULL
)

CREATE UNIQUE INDEX public_key_index1 ON public_key_info(user_id, pub_key_token)

CREATE TABLE secret_key_info (
  	_id        INTEGER PRIMARY KEY AUTOINCREMENT,
  	chat_id    INTEGER NOT NULL,
  	secret_key_token INTEGER NOT NULL,
  	secret_key TEXT,
  	create_at  INTEGER
)

CREATE UNIQUE INDEX secret_key_index1 ON secret_key_info(chat_id, secret_key_token)
CREATE INDEX secret_key_index2 ON secret_key_info(create_at)

CREATE TABLE chat_logs (
  _id        INTEGER PRIMARY KEY AUTOINCREMENT,
  id          INTEGER NOT NULL,
  type        INTEGER,
  chat_id     INTEGER NOT NULL,
  user_id     INTEGER,
  message     TEXT,
  attachment  TEXT,
  created_at  INTEGER,
  deleted_at	INTEGER DEFAULT 0,
  client_message_id		INTEGER,
  v TEXT
)
CREATE UNIQUE INDEX chat_logs_index1 ON chat_logs(chat_id, id)
CREATE INDEX chat_logs_index4 on chat_logs(chat_id, type)

CREATE TABLE chat_sending_logs (
  _id        INTEGER PRIMARY KEY AUTOINCREMENT,
  type        INTEGER,
  chat_id     INTEGER NOT NULL,
  message     TEXT,
  attachment    TEXT,
  status      INTEGER,
  offset      INTEGER,
  created_at    INTEGER,
  client_message_id		INTEGER,
  v TEXT
)
CREATE INDEX chat_sending_logs_index1 on chat_sending_logs(chat_id)
