CREATE TABLE schema_migrations (
	version INTEGER NOT NULL
)

CREATE TABLE friends (
	_id INTEGER PRIMARY KEY AUTOINCREMENT,
	contact_id INTEGER,
	id INTEGER,
	type INTEGER NOT NULL,
	uuid TEXT,
	phone_number TEXT NOT NULL,
	raw_phone_number TEXT,
	name TEXT NOT NULL,
	phonetic_name TEXT,
	profile_image_url TEXT,
	full_profile_image_url TEXT,
	original_profile_image_url TEXT,
	status_message TEXT,
	chat_id INTEGER NOT NULL,
	brand_new INTEGER NOT NULL,
	blocked INTEGER NOT NULL,
	favorite INTEGER NOT NULL,
	position INTEGER NOT NULL,
	v TEXT,
	board_v TEXT,
	ext TEXT,
	nick_name TEXT,
	user_type INTEGER NOT NULL,
	story_user_id INTEGER,
	account_id INTEGER,
	linked_services TEXT,
	hidden INTEGER NOT NULL,
	purged INTEGER DEFAULT 0 NOT NULL,
	member_type INTEGER DEFAULT 0 NOT NULL, /* 1:Friend, 0:Not Freind */
	involved_chat_ids TEXT,
	contact_name TEXT,
	enc INTEGER,
	created_at INTEGER,
	new_badge_updated_at INTEGER,
	new_badge_seen_at INTEGER
)
CREATE UNIQUE INDEX friends_index1 ON friends(id)
CREATE INDEX friends_index2 ON friends(name)
CREATE INDEX friends_index3 ON friends(phone_number)
CREATE INDEX friends_index4 ON friends(contact_id)
CREATE INDEX friends_index5 ON friends(brand_new)
CREATE INDEX friends_index6 ON friends(position)
CREATE INDEX friends_index7 ON friends(member_type)

CREATE TABLE block_friends (
	_id INTEGER PRIMARY KEY AUTOINCREMENT,
	id INTEGER UNIQUE NOT NULL,
	nickname TEXT,
	profile_image_url TEXT
)

CREATE TABLE channel_cards (
	_id INTEGER PRIMARY KEY AUTOINCREMENT,
	id TEXT UNIQUE,
	card_order INTEGER,
	v TEXT,
	like_clicked INTEGER
)

CREATE TABLE cover_feeds (
	_id INTEGER PRIMARY KEY AUTOINCREMENT,
	sender TEXT,
	message TEXT,
	sent_at INTEGER,
    details TEXT
)

CREATE TABLE recently_emoticons (
  emoticon_id	INTEGER PRIMARY KEY, /*item_resource._id or DefaultEmoticonRes*/
  last_used_at	INTEGER,
  count_used	INTEGER,
  v TEXT,
  item_id TEXT DEFAULT 0/*item.id*/
)


CREATE TABLE item (
  id TEXT PRIMARY KEY,
  category INTEGER NOT NULL,
  set_order INTEGER,
  dw_complete TEXT,
  sv BLOB,
  v TEXT
)

CREATE TABLE item_resource (
	_id INTEGER PRIMARY KEY AUTOINCREMENT,
	item_category INTEGER NOT NULL, /*item.category*/
	item_id TEXT NOT NULL, /*item.id*/
	sv BLOB,
	v TEXT
)

CREATE TABLE track_logs (
	_id INTEGER PRIMARY KEY AUTOINCREMENT,
	date TEXT,
	page_id TEXT,
	action_id INTEGER,
	count INTEGER NOT NULL DEFAULT 1,
	metadata TEXT
)
CREATE UNIQUE INDEX track_logs_index1 ON track_logs(date, page_id, action_id, metadata)

CREATE TABLE wifi_cache (
	_id INTEGER PRIMARY KEY AUTOINCREMENT,
	ssid TEXT UNIQUE,
	host TEXT,
	port INTEGER,
	secure_type INTEGER,
	updated_at INTEGER
)

CREATE TABLE wifi_cache_bssid (
	_id INTEGER PRIMARY KEY AUTOINCREMENT,
	cache_id INTEGER, /* wifi_cache._id */
	bssid TEXT UNIQUE,
	host TEXT,
	port INTEGER,
	secure_type INTEGER,
	updated_at INTEGER
)

CREATE TABLE friends_board_contents (
	_id INTEGER PRIMARY KEY AUTOINCREMENT,
	friend_id INTEGER,
	type INTEGER,
	image_url TEXT,
	thumbnail_url TEXT,
	url TEXT,
	v TEXT,
	enc INTEGER
)
CREATE INDEX friends_board_contents_index1 ON friends_board_contents(friend_id)

CREATE TABLE open_link (
	id INTEGER PRIMARY KEY,
	user_id INTEGER NOT NULL,
	token INTEGER,
	name TEXT,
	url TEXT,
	image_url TEXT,
	type INTEGER DEFAULT 1,
	member_limit INTEGER DEFAULT -1,
	direct_chat_limit INTEGER DEFAULT -1,
	active INTEGER DEFAULT 1,
	expired INTEGER DEFAULT 0,
	created_at INTEGER,
	view_type INTEGER,
	push_alert INTEGER DEFAULT 1,
	icon_url TEXT,
	v TEXT
)
CREATE INDEX open_link_index1 ON open_link(id)

CREATE TABLE open_profile (
    link_id INTEGER PRIMARY KEY,
    user_id INTEGER NOT NULL,
    profile_type INTEGER NOT NULL,
    nickname TEXT,
    profile_image_url TEXT,
    f_profile_image_url TEXT,
    o_profile_image_url TEXT,
    token INTEGER DEFAULT 0,
    v TEXT
)
CREATE INDEX open_profile_index1 ON open_profile(link_id)

CREATE TABLE grouping (
	grouping_id INTEGER PRIMARY KEY,
    name TEXT,
    image_url TEXT,
    user_ids TEXT,
    pos INTEGER,
    v TEXT
)
CREATE INDEX grouping_index1 ON grouping(grouping_id)
